@@ -1,4 +1,4 @@
-version_info = (2, 1, 14)
+version_info = (2, 2, 0)
 
 __version__ = version = '.'.join(map(str, version_info))
 __project__ = PROJECT = __name__
@@ -7,9 +7,13 @@ __license__ = LICENSE = "GNU LGPL"
 
 try:
     from django.conf import settings as django_settings # nolint
-    if django_settings.configured \
-       and not 'adrest' in django_settings.INSTALLED_APPS:
-        import logging
-        logging.warn('You should add "adrest" to INSTALLED_APPS.')
+    if django_settings.configured:
+
+        if not 'adrest' in django_settings.INSTALLED_APPS:
+            import logging
+            logging.warn('You should add "adrest" to INSTALLED_APPS.')
+
 except ImportError:
     pass
+
+# lint_ignore=W402
